@@ -108,10 +108,10 @@ def execute_cmdline_scenarios(scenario_name, args, command_args, ansible_args=()
 
         if scenario.config.config["prerun"]:
             LOG.info("Performing prerun...")
-            scenario.config.runtime.prepare_environment()
+            scenario.config.runtime.prepare_environment(install_local=True)
 
         if command_args.get("subcommand") == "reset":
-            LOG.info("Removing %s" % scenario.ephemeral_directory)
+            LOG.info("Removing %s", scenario.ephemeral_directory)
             shutil.rmtree(scenario.ephemeral_directory)
             return
         try:
@@ -121,9 +121,9 @@ def execute_cmdline_scenarios(scenario_name, args, command_args, ansible_args=()
             # handle that behavior here.
             if command_args.get("destroy") == "always":
                 msg = (
-                    "An error occurred during the {} sequence action: "
-                    "'{}'. Cleaning up."
-                ).format(scenario.config.subcommand, scenario.config.action)
+                    f"An error occurred during the {scenario.config.subcommand} sequence action: "
+                    f"'{scenario.config.action}'. Cleaning up."
+                )
                 LOG.warning(msg)
                 execute_subcommand(scenario.config, "cleanup")
                 execute_subcommand(scenario.config, "destroy")
@@ -206,13 +206,11 @@ def _verify_configs(configs, glob_str=MOLECULE_GLOB):
         scenario_names = [c.scenario.name for c in configs]
         for scenario_name, n in collections.Counter(scenario_names).items():
             if n > 1:
-                msg = ("Duplicate scenario name '{}' found.  " "Exiting.").format(
-                    scenario_name
-                )
+                msg = f"Duplicate scenario name '{scenario_name}' found.  Exiting."
                 util.sysexit_with_message(msg)
 
     else:
-        msg = "'{}' glob failed.  Exiting.".format(glob_str)
+        msg = f"'{glob_str}' glob failed.  Exiting."
         util.sysexit_with_message(msg)
 
 
