@@ -19,16 +19,17 @@
 #  DEALINGS IN THE SOFTWARE.
 """Destroy Command Module."""
 
+import logging
 import os
 
 import click
 
-from molecule import logger, util
+from molecule import util
 from molecule.api import drivers
 from molecule.command import base
 from molecule.config import DEFAULT_DRIVER
 
-LOG = logger.get_logger(__name__)
+LOG = logging.getLogger(__name__)
 MOLECULE_PARALLEL = os.environ.get("MOLECULE_PARALLEL", False)
 
 
@@ -113,9 +114,7 @@ class Destroy(base.Base):
     "--scenario-name",
     "-s",
     default=base.MOLECULE_DEFAULT_SCENARIO_NAME,
-    help="Name of the scenario to target. ({})".format(
-        base.MOLECULE_DEFAULT_SCENARIO_NAME
-    ),
+    help=f"Name of the scenario to target. ({base.MOLECULE_DEFAULT_SCENARIO_NAME})",
 )
 @click.option(
     "--driver-name",
