@@ -61,7 +61,7 @@ class Prepare(base.Base):
 
     .. option:: molecule prepare --force
 
-        Force the execution fo the prepare playbook.
+        Force the execution for the prepare playbook.
 
     .. program:: molecule --debug prepare
 
@@ -110,9 +110,7 @@ class Prepare(base.Base):
     "--scenario-name",
     "-s",
     default=base.MOLECULE_DEFAULT_SCENARIO_NAME,
-    help="Name of the scenario to target. ({})".format(
-        base.MOLECULE_DEFAULT_SCENARIO_NAME
-    ),
+    help=f"Name of the scenario to target. ({base.MOLECULE_DEFAULT_SCENARIO_NAME})",
 )
 @click.option(
     "--driver-name",
