@@ -79,9 +79,7 @@ class Syntax(base.Base):
     "--scenario-name",
     "-s",
     default=base.MOLECULE_DEFAULT_SCENARIO_NAME,
-    help="Name of the scenario to target. ({})".format(
-        base.MOLECULE_DEFAULT_SCENARIO_NAME
-    ),
+    help=f"Name of the scenario to target. ({base.MOLECULE_DEFAULT_SCENARIO_NAME})",
 )
 def syntax(ctx, scenario_name):  # pragma: no cover
     """Use the provisioner to syntax check the role."""
