@@ -27,10 +27,10 @@ from typing import MutableMapping
 from uuid import uuid4
 
 from ansible_compat.ports import cache, cached_property
-from ansible_compat.runtime import Runtime
 from packaging.version import Version
 
 from molecule import api, interpolation, platforms, scenario, state, util
+from molecule.app import app
 from molecule.dependency import ansible_galaxy, shell
 from molecule.model import schema_v3
 from molecule.provisioner import ansible
@@ -52,7 +52,7 @@ def ansible_version() -> Version:
         "molecule.config.ansible_version is deprecated, will be removed in the future.",
         category=DeprecationWarning,
     )
-    return Runtime().version
+    return app.runtime.version
 
 
 # https://stackoverflow.com/questions/16017397/injecting-function-call-after-init-with-decorator  # noqa
@@ -106,7 +106,7 @@ class Config(object, metaclass=NewInitCaller):
         self._action = None
         self._run_uuid = str(uuid4())
         self.project_directory = os.getenv("MOLECULE_PROJECT_DIRECTORY", os.getcwd())
-        self.runtime = Runtime(isolated=True)
+        self.runtime = app.runtime
 
     def after_init(self):
         self.config = self._reget_config()
@@ -239,9 +239,9 @@ class Config(object, metaclass=NewInitCaller):
 
         if driver_from_cli and (driver_from_cli != driver_name):
             msg = (
-                "Instance(s) were created with the '{}' driver, but the "
-                "subcommand is using '{}' driver."
-            ).format(driver_name, driver_from_cli)
+                f"Instance(s) were created with the '{driver_name}' driver, but the "
+                f"subcommand is using '{driver_from_cli}' driver."
+            )
             util.sysexit_with_message(msg)
 
         return driver_name
@@ -315,8 +315,8 @@ class Config(object, metaclass=NewInitCaller):
         try:
             return i.interpolate(stream, keep_string)
         except interpolation.InvalidInterpolation as e:
-            msg = "parsing config file '{}'.\n\n" "{}\n{}".format(
-                self.molecule_file, e.place, e.string
+            msg = (
+                f"parsing config file '{self.molecule_file}'.\n\n{e.place}\n{e.string}"
             )
             util.sysexit_with_message(msg)
         return ""
@@ -417,11 +417,11 @@ class Config(object, metaclass=NewInitCaller):
         env = set_env_from_file(os.environ.copy(), self.env_file)
         errors, data = schema_v3.pre_validate(data, env, MOLECULE_KEEP_STRING)
         if errors:
-            msg = "Failed to pre-validate.\n\n{}".format(errors)
+            msg = f"Failed to pre-validate.\n\n{errors}"
             util.sysexit_with_message(msg, detail=data)
 
     def _validate(self):
-        msg = "Validating schema {}.".format(self.molecule_file)
+        msg = f"Validating schema {self.molecule_file}."
         LOG.debug(msg)
 
         errors = schema_v3.validate(self.config)
