@@ -459,6 +459,7 @@ class Ansible(base.Base):
                         *os.environ.get("ANSIBLE_ROLES_PATH", "").split(":"),
                     ]
                 ),
+                self._config.ansible_collections_path: ":".join(collections_path_list),
                 "ANSIBLE_LIBRARY": ":".join(self._get_modules_directories()),
                 "ANSIBLE_FILTER_PLUGINS": ":".join(
                     [
@@ -530,19 +531,19 @@ class Ansible(base.Base):
 
         try:
             path = self._absolute_path_for(env, "ANSIBLE_ROLES_PATH")
-            roles_path = "{}:{}".format(roles_path, path)
+            roles_path = f"{roles_path}:{path}"
         except KeyError:
             pass
 
         try:
             path = self._absolute_path_for(env, "ANSIBLE_LIBRARY")
-            library_path = "{}:{}".format(library_path, path)
+            library_path = f"{library_path}:{path}"
         except KeyError:
             pass
 
         try:
             path = self._absolute_path_for(env, "ANSIBLE_FILTER_PLUGINS")
-            filter_plugins_path = "{}:{}".format(filter_plugins_path, path)
+            filter_plugins_path = f"{filter_plugins_path}:{path}"
         except KeyError:
             pass
 
@@ -852,9 +853,9 @@ class Ansible(base.Base):
             source = os.path.join(self._config.scenario.directory, source)
 
             if not os.path.exists(source):
-                msg = "The source path '{}' does not exist.".format(source)
+                msg = f"The source path '{source}' does not exist."
                 util.sysexit_with_message(msg)
-            msg = "Inventory {} linked to {}".format(source, target)
+            msg = f"Inventory {source} linked to {target}"
             LOG.info(msg)
             os.symlink(source, target)
 
@@ -916,7 +917,7 @@ class Ansible(base.Base):
 
         Adds modules directory from molecule and its plugins.
         """
-        paths: List[Optional[str]] = list()
+        paths: List[Optional[str]] = []
         if os.environ.get("ANSIBLE_LIBRARY"):
             paths = list(map(util.abs_path, os.environ["ANSIBLE_LIBRARY"].split(":")))
 
