@@ -19,6 +19,7 @@
 #  DEALINGS IN THE SOFTWARE.
 """Molecule Scenario Module."""
 
+import errno
 import fcntl
 import fnmatch
 import logging
@@ -106,7 +107,7 @@ class Scenario(object):
         :return: None
         """
         directory = str(Path(self.ephemeral_directory).parent)
-        LOG.info("Removing {}".format(directory))
+        LOG.info("Removing %s", directory)
         shutil.rmtree(directory)
 
     def prune(self):
@@ -129,7 +130,11 @@ class Scenario(object):
         files = util.os_walk(self.ephemeral_directory, "*")
         for f in files:
             if not any(sf for sf in safe_files if fnmatch.fnmatch(f, sf)):
-                os.remove(f)
+                try:
+                    os.remove(f)
+                except OSError as e:
+                    if e.errno != errno.ENOENT:
+                        raise
 
         # Remove empty directories.
         for dirpath, dirs, files in os.walk(self.ephemeral_directory, topdown=False):
@@ -155,9 +160,7 @@ class Scenario(object):
             project_directory = os.path.basename(self.config.project_directory)
 
             if self.config.is_parallel:
-                project_directory = "{}-{}".format(
-                    project_directory, self.config._run_uuid
-                )
+                project_directory = f"{project_directory}-{self.config._run_uuid}"
 
             project_scenario_directory = os.path.join(
                 self.config.cache_directory, project_directory, self.name
@@ -268,7 +271,7 @@ class Scenario(object):
         :return: None
         """
         if not os.path.isdir(self.inventory_directory):
-            os.makedirs(self.inventory_directory)
+            os.makedirs(self.inventory_directory, exist_ok=True)
 
 
 def ephemeral_directory(path: Optional[str] = None) -> str:
