@@ -18,6 +18,7 @@
 #  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 #  DEALINGS IN THE SOFTWARE.
 
+import os
 from typing import Optional
 
 import pytest
@@ -77,6 +78,7 @@ def test_command_check(scenario_to_test, with_scenario, scenario_name):
     ],
     indirect=["scenario_to_test", "driver_name", "scenario_name"],
 )
+@pytest.mark.serial
 def test_command_cleanup(scenario_to_test, with_scenario, scenario_name):
     cmd = ["molecule", "cleanup", "--scenario-name", scenario_name]
     assert run_command(cmd).returncode == 0
@@ -90,6 +92,7 @@ def test_command_cleanup(scenario_to_test, with_scenario, scenario_name):
     ],
     indirect=["scenario_to_test", "driver_name", "scenario_name"],
 )
+@pytest.mark.serial
 def test_command_converge(scenario_to_test, with_scenario, scenario_name):
     cmd = ["molecule", "converge", "--scenario-name", scenario_name]
     assert run_command(cmd).returncode == 0
@@ -103,9 +106,15 @@ def test_command_converge(scenario_to_test, with_scenario, scenario_name):
     ],
     indirect=["scenario_to_test", "driver_name", "scenario_name"],
 )
-def test_command_create(scenario_to_test, with_scenario, scenario_name):
+@pytest.mark.serial
+def test_command_create(scenario_to_test, with_scenario, scenario_name, tmp_path):
+    os.environ["ANSIBLE_ROLES_PATH"] = str(tmp_path)
     cmd = ["molecule", "create", "--scenario-name", scenario_name]
-    assert run_command(cmd).returncode == 0
+    assert run_command(cmd, env=os.environ).returncode == 0
+
+    # Validate that ansible-compat created a symlink in the roles path
+    role_path = tmp_path / "molecule.delegated_test"
+    assert role_path.is_symlink()
 
 
 @pytest.mark.parametrize(
@@ -132,6 +141,7 @@ def test_command_create(scenario_to_test, with_scenario, scenario_name):
     ],
     indirect=["scenario_to_test", "driver_name", "scenario_name"],
 )
+@pytest.mark.serial
 def test_command_dependency(request, scenario_to_test, with_scenario, scenario_name):
     cmd = ["molecule", "dependency", "--scenario-name", scenario_name]
     assert run_command(cmd, echo=True).returncode == 0
@@ -141,6 +151,7 @@ def test_command_dependency(request, scenario_to_test, with_scenario, scenario_n
     assert run_command(cmd, echo=True).returncode == 0
 
 
+@pytest.mark.serial
 @pytest.mark.extensive
 @pytest.mark.parametrize(
     "scenario_to_test, driver_name, scenario_name",
@@ -152,6 +163,7 @@ def test_command_destroy(scenario_to_test, with_scenario, scenario_name):
     assert run_command(cmd).returncode == 0
 
 
+@pytest.mark.serial
 @pytest.mark.extensive
 @pytest.mark.parametrize(
     "scenario_to_test, driver_name, scenario_name",
@@ -164,18 +176,21 @@ def test_command_idempotence(scenario_to_test, with_scenario, scenario_name):
     idempotence(scenario_name)
 
 
+@pytest.mark.serial
 @pytest.mark.parametrize("driver_name", [("delegated")], indirect=["driver_name"])
 @pytest.mark.xfail(reason="https://github.com/ansible-community/molecule/issues/3171")
 def test_command_init_role(temp_dir, driver_name, skip_test):
     init_role(temp_dir, driver_name)
 
 
+@pytest.mark.serial
 @pytest.mark.parametrize("driver_name", [("delegated")], indirect=["driver_name"])
 @pytest.mark.xfail(reason="https://github.com/ansible-community/molecule/issues/3171")
 def test_command_init_scenario(temp_dir, driver_name, skip_test):
     init_scenario(temp_dir, driver_name)
 
 
+@pytest.mark.serial
 @pytest.mark.extensive
 @pytest.mark.parametrize(
     "scenario_to_test, driver_name, scenario_name",
@@ -189,6 +204,7 @@ def test_command_lint(scenario_to_test, with_scenario, scenario_name):
     assert run_command(cmd).returncode == 0
 
 
+@pytest.mark.serial
 @pytest.mark.parametrize(
     "scenario_to_test, driver_name, expected",
     [
@@ -220,6 +236,7 @@ def test_command_list_with_format_plain(scenario_to_test, with_scenario, expecte
 #     login(login_args, scenario_name)
 
 
+@pytest.mark.serial
 @pytest.mark.extensive
 @pytest.mark.parametrize(
     "scenario_to_test, driver_name, scenario_name",
@@ -236,6 +253,7 @@ def test_command_prepare(scenario_to_test, with_scenario, scenario_name):
     assert run_command(cmd).returncode == 0
 
 
+@pytest.mark.serial
 @pytest.mark.extensive
 @pytest.mark.parametrize(
     "scenario_to_test, driver_name, scenario_name",
@@ -249,6 +267,7 @@ def test_command_side_effect(scenario_to_test, with_scenario, scenario_name):
     assert run_command(cmd).returncode == 0
 
 
+@pytest.mark.serial
 @pytest.mark.extensive
 @pytest.mark.parametrize(
     "scenario_to_test, driver_name, scenario_name",
@@ -262,6 +281,7 @@ def test_command_syntax(scenario_to_test, with_scenario, scenario_name):
     assert run_command(cmd).returncode == 0
 
 
+@pytest.mark.serial
 @pytest.mark.parametrize(
     "scenario_to_test, driver_name, scenario_name",
     [
@@ -273,6 +293,7 @@ def test_command_test(scenario_to_test, with_scenario, scenario_name, driver_nam
     run_test(driver_name, scenario_name)
 
 
+@pytest.mark.serial
 @pytest.mark.extensive
 @pytest.mark.parametrize(
     "scenario_to_test, driver_name, scenario_name",
