@@ -36,8 +36,8 @@ import jinja2
 import yaml
 from ansible_compat.ports import cache
 from rich.syntax import Syntax
-from subprocess_tee import run
 
+from molecule.app import app
 from molecule.console import console
 from molecule.constants import MOLECULE_HEADER
 
@@ -77,7 +77,7 @@ def print_environment_vars(env: Optional[Dict[str, str]]) -> None:
         combined_env.update(molecule_env)
         print_debug(
             "SHELL REPLAY",
-            " ".join(["{}={}".format(k, v) for (k, v) in sorted(combined_env.items())]),
+            " ".join([f"{k}={v}" for (k, v) in sorted(combined_env.items())]),
         )
         print()
 
@@ -130,8 +130,6 @@ def run_command(
     :param debug: An optional bool to toggle debug output.
     """
     args = []
-    stdout = None
-    stderr = None
     if cmd.__class__.__name__ == "Command":
         raise RuntimeError(
             "Molecule 3.2.0 dropped use of sh library, update plugin code to use new API. "
@@ -143,22 +141,17 @@ def run_command(
         else:
             env = cmd.env or env
         args = cmd.cmd
-        stdout = cmd.stdout
-        stderr = cmd.stderr
     else:
         args = cmd
 
     if debug:
         print_environment_vars(env)
 
-    result = run(
-        args,
+    result = app.runtime.exec(
+        args=args,
         env=env,
-        stdout=stdout,
-        stderr=stderr,
-        echo=echo or debug,
-        quiet=quiet,
         cwd=cwd,
+        tee=True,
     )
     if result.returncode != 0 and check:
         raise CalledProcessError(
@@ -189,26 +182,28 @@ def render_template(template, **kwargs):
     return t.render(kwargs)
 
 
-def write_file(filename: str, content: str):
+def write_file(filename: str, content: str, header: Optional[str] = None) -> None:
     """
     Write a file with the given filename and content and returns None.
 
     :param filename: A string containing the target filename.
     :param content: A string containing the data to be written.
+    :param header: A header, if None it will use default header.
     :return: None
     """
+    if header is None:
+        content = MOLECULE_HEADER + "\n\n" + content
+
     with open_file(filename, "w") as f:
         f.write(content)
 
-    file_prepender(filename)
 
-
-def molecule_prepender(content: str):
+def molecule_prepender(content: str) -> str:
     """Return molecule identification header."""
     return MOLECULE_HEADER + "\n\n" + content
 
 
-def file_prepender(filename: str):
+def file_prepender(filename: str) -> None:
     """
     Prepend an informational header on files managed by Molecule and returns \
     None.
@@ -274,7 +269,7 @@ def open_file(filename, mode="r"):
 
 def instance_with_scenario_name(instance_name, scenario_name):
     """Format instance name that includes scenario."""
-    return "{}-{}".format(instance_name, scenario_name)
+    return f"{instance_name}-{scenario_name}"
 
 
 def verbose_flag(options):
@@ -283,7 +278,7 @@ def verbose_flag(options):
     verbose_flag = []
     for i in range(0, 3):
         if options.get(verbose):
-            verbose_flag = ["-{}".format(verbose)]
+            verbose_flag = [f"-{verbose}"]
             del options[verbose]
             if options.get("verbose"):
                 del options["verbose"]
@@ -335,7 +330,7 @@ def validate_parallel_cmd_args(cmd_args):
 
 def _parallelize_platforms(config, run_uuid):
     def parallelize(platform):
-        platform["name"] = "{}-{}".format(platform["name"], run_uuid)
+        platform["name"] = f"{platform['name']}-{run_uuid}"
         return platform
 
     return [parallelize(platform) for platform in config["platforms"]]
@@ -357,7 +352,7 @@ def find_vcs_root(location="", dirs=(".git", ".hg", ".svn"), default=None) -> st
 def lookup_config_file(filename: str) -> Optional[str]:
     """Return config file PATH."""
     for path in [find_vcs_root(default="~"), "~"]:
-        f = os.path.expanduser("%s/%s" % (path, filename))
+        f = os.path.expanduser(f"{path}/{filename}")
         if os.path.isfile(f):
             LOG.info("Found config file %s", f)
             return f
@@ -385,8 +380,7 @@ def boolean(value: Any, strict=True) -> bool:
         return False
 
     raise TypeError(
-        "The value '%s' is not a valid boolean.  Valid booleans include: %s"
-        % (str(value), ", ".join(repr(i) for i in BOOLEANS))
+        f"The value '{value!s}' is not a valid boolean.  Valid booleans include: {', '.join(repr(i) for i in BOOLEANS)!s}"
     )
 
 
