@@ -20,12 +20,13 @@
 """Testinfra Verifier Module."""
 
 import glob
+import logging
 import os
 
-from molecule import logger, util
+from molecule import util
 from molecule.api import Verifier
 
-LOG = logger.get_logger(__name__)
+LOG = logging.getLogger(__name__)
 
 
 class Testinfra(Verifier):
@@ -178,7 +179,7 @@ class Testinfra(Verifier):
         if self._testinfra_command is None:
             self.bake()
 
-        msg = "Executing Testinfra tests found in {}/...".format(self.directory)
+        msg = f"Executing Testinfra tests found in {self.directory}/..."
         LOG.info(msg)
 
         result = util.run_command(self._testinfra_command, debug=self._config.debug)
@@ -195,7 +196,12 @@ class Testinfra(Verifier):
         :return: list
         """
         return sorted(
-            [filename for filename in util.os_walk(self.directory, "test_*.py")]
+            [
+                filename
+                for filename in util.os_walk(
+                    self.directory, "test_*.py", followlinks=True
+                )
+            ]
         )
 
     def schema(self):
